Struct sp_plugin_rust_test::Shurjopay::SpAuthToken
source · pub struct SpAuthToken {
pub token: String,
pub store_id: i32,
pub execute_url: String,
pub token_type: String,
pub sp_code: String,
pub message: String,
pub token_create_time: String,
pub expires_in: i64,
}Expand description
Shurjopay token authorization data structure
This structure implements Serialize, Deserialize, Debug and Clone functions
Fields
token: Stringstore_id: i32execute_url: Stringtoken_type: Stringsp_code: Stringmessage: Stringtoken_create_time: Stringexpires_in: i64Implementations
sourceimpl SpAuthToken
impl SpAuthToken
implementation for SpAuthToken
sourcepub fn get_time(&self) -> Option<NaiveDateTime>
pub fn get_time(&self) -> Option<NaiveDateTime>
Takes SpAuthToken structure and and converts String timestamp stored in SpAuthToken.token_create_time
return time in NativeDateTime