pub struct SpCheckout {
Show 14 fields pub prefix: String, pub token: String, pub return_url: String, pub cancel_url: String, pub store_id: String, pub amount: String, pub order_id: String, pub currency: String, pub customer_name: String, pub customer_address: String, pub customer_phone: String, pub customer_city: String, pub customer_post_code: String, pub client_ip: String,
}
Shurjopay checkout data structure This structure implements Serialize, Deserialize, Debug and Clone functions Each element of the structure must hold a value before checking out

Fields

prefix: Stringtoken: Stringreturn_url: Stringcancel_url: Stringstore_id: Stringamount: Stringorder_id: Stringcurrency: Stringcustomer_name: Stringcustomer_address: Stringcustomer_phone: Stringcustomer_city: Stringcustomer_post_code: Stringclient_ip: String