pub struct SpConfig {
    pub post_default_address: String,
    pub token_end_point: String,
    pub secure_payment_end_point: String,
    pub verification_end_point: String,
    pub payment_status_end_point: String,
    pub sp_user: String,
    pub sp_pass: String,
    pub default_return_url: String,
    pub default_cancel_url: String,
    pub default_client_ip: String,
}
Shurjopay configuration data structure This structure should be declared as non mutable and ownership shouldn’t be transferred to any other instance This structure implements Serialize, Deserialize, Debug and Clone functions

Fields

post_default_address: Stringtoken_end_point: Stringsecure_payment_end_point: Stringverification_end_point: Stringpayment_status_end_point: Stringsp_user: Stringsp_pass: Stringdefault_return_url: Stringdefault_cancel_url: Stringdefault_client_ip: String