pub struct SpVerifyResponse2 { /* private fields */ }
Shurjopay payment another verifiacation data structure This structure comes when payment is not successful This structure implements Serialize, Deserialize, Debug and Clone functions

Implementations

implementation for SpVerifyResponse2

This is a constructor to initiate null instance of SpVerifyResponse2 returns SpVerifyResponse2

This function unwraps JSON String into SpVerifyResponse2 data structure’ if conversion is possible return true