Struct sp_plugin_rust_test::Shurjopay::SpCheckout
source · pub struct SpCheckout {Show 14 fields
pub prefix: String,
pub token: String,
pub return_url: String,
pub cancel_url: String,
pub store_id: String,
pub amount: String,
pub order_id: String,
pub currency: String,
pub customer_name: String,
pub customer_address: String,
pub customer_phone: String,
pub customer_city: String,
pub customer_post_code: String,
pub client_ip: String,
}Expand description
Shurjopay checkout data structure
This structure implements Serialize, Deserialize, Debug and Clone functions
Each element of the structure must hold a value before checking out
Fields
prefix: Stringtoken: Stringreturn_url: Stringcancel_url: Stringstore_id: Stringamount: Stringorder_id: Stringcurrency: Stringcustomer_name: Stringcustomer_address: Stringcustomer_phone: Stringcustomer_city: Stringcustomer_post_code: Stringclient_ip: StringTrait Implementations
sourceimpl Clone for SpCheckout
impl Clone for SpCheckout
sourcefn clone(&self) -> SpCheckout
fn clone(&self) -> SpCheckout
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SpCheckout
impl Debug for SpCheckout
sourceimpl Default for SpCheckout
impl Default for SpCheckout
sourceimpl<'de> Deserialize<'de> for SpCheckout
impl<'de> Deserialize<'de> for SpCheckout
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more